@@ -1,5 +1,5 @@
 /*
-  Copyright 2011-2012 David Robillard <http://drobilla.net>
+  Copyright 2011-2013 David Robillard <http://drobilla.net>
 
   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -113,7 +113,6 @@ public:
 		: _next_blank_id(0)
 	{
 		_c_obj = sord_world_new();
-		add_prefix("rdf", "http://www.w3.org/1999/02/22-rdf-syntax-ns#");
 	}
 
 	inline ~World() {
@@ -151,6 +150,7 @@ public:
 	inline Node(World& world, Type t, const std::string& s);
 	inline Node(World& world);
 	inline Node(World& world, const SordNode* node);
+	inline Node(World& world, SordNode* node, bool copy=false);
 	inline Node(const Node& other);
 	inline ~Node();
 
@@ -161,6 +161,10 @@ public:
 	inline const SordNode* get_node() const { return _c_obj; }
 	inline SordNode*       get_node()       { return _c_obj; }
 
+	const SerdNode* to_serd_node() {
+		return sord_node_to_serd_node(_c_obj);
+	}
+
 	inline bool is_valid() const { return type() != UNKNOWN; }
 
 	inline bool operator<(const Node& other) const {
@@ -240,6 +244,30 @@ class Literal : public Node {
 public:
 	inline Literal(World& world, const std::string& s)
 		: Node(world, Node::LITERAL, s) {}
+
+	static inline Node decimal(World& world, double d, unsigned frac_digits) {
+		const SerdNode val  = serd_node_new_decimal(d, 7);
+		const SerdNode type = serd_node_from_string(
+			SERD_URI, (const uint8_t*)SORD_NS_XSD "decimal");
+
+		return Node(
+			world,
+			sord_node_from_serd_node(
+				world.c_obj(), world.prefixes().c_obj(), &val, &type, NULL),
+			false);
+	}
+
+	static inline Node integer(World& world, int64_t i) {
+		const SerdNode val  = serd_node_new_integer(i);
+		const SerdNode type = serd_node_from_string(
+			SERD_URI, (const uint8_t*)SORD_NS_XSD "integer");
+
+		return Node(
+			world,
+			sord_node_from_serd_node(
+				world.c_obj(), world.prefixes().c_obj(), &val, &type, NULL),
+			false);
+	}
 };
 
 inline
@@ -278,7 +306,14 @@ inline
 Node::Node(World& world, const SordNode* node)
 	: _world(&world)
 {
-	_c_obj = node ? sord_node_copy(node) : NULL;
+	_c_obj = sord_node_copy(node);
+}
+
+inline
+Node::Node(World& world, SordNode* node, bool copy)
+	: _world(&world)
+{
+	_c_obj = copy ? sord_node_copy(node) : node;
 }
 
 inline
@@ -431,6 +466,10 @@ public:
 	                 const Node& predicate,
 	                 const Node& object);
 
+	inline Node get(const Node& subject,
+	                const Node& predicate,
+	                const Node& object);
+
 	inline World& world() const { return _world; }
 
 private:
@@ -596,6 +635,18 @@ Model::find(const Node& subject,
 	return Iter(_world, sord_find(_c_obj, quad));
 }
 
+inline Node
+Model::get(const Node& subject,
+           const Node& predicate,
+           const Node& object)
+{
+	SordNode* c_node = sord_get(
+		_c_obj, subject.c_obj(), predicate.c_obj(), object.c_obj(), NULL);
+	Node node(_world, c_node);
+	sord_node_free(_world.c_obj(), c_node);
+	return node;
+}
+
 }  // namespace Sord
 
 #endif  // SORD_SORDMM_HPP
