@@ -1,5 +1,5 @@
 /*
-  Copyright 2011 David Robillard <http://drobilla.net>
+  Copyright 2011-2013 David Robillard <http://drobilla.net>
 
   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -844,6 +844,31 @@ sord_search(SordModel*      model,
 	return sord_find(model, pat);
 }
 
+SordNode*
+sord_get(SordModel*      model,
+         const SordNode* s,
+         const SordNode* p,
+         const SordNode* o,
+         const SordNode* g)
+{
+	if ((bool)s + (bool)p + (bool)o != 2) {
+		return NULL;
+	}
+
+	SordIter* i   = sord_search(model, s, p, o, g);
+	SordNode* ret = NULL;
+	if (!s) {
+		ret = sord_node_copy(sord_iter_get_node(i, SORD_SUBJECT));
+	} else if (!p) {
+		ret = sord_node_copy(sord_iter_get_node(i, SORD_PREDICATE));
+	} else if (!o) {
+		ret = sord_node_copy(sord_iter_get_node(i, SORD_OBJECT));
+	}
+
+	sord_iter_free(i);
+	return ret;
+}
+
 bool
 sord_ask(SordModel*      model,
          const SordNode* s,
