@@ -22,16 +22,25 @@
 
 #include "sord/sord.h"
 
+/** Resource node metadata */
+typedef struct {
+	size_t refs_as_obj;  ///< References as a quad object
+} SordResourceMetadata;
+
+/** Literal node metadata */
+typedef struct {
+	SordNode* datatype;  ///< Optional literal data type URI
+	char      lang[16];  ///< Optional language tag
+} SordLiteralMetadata;
+
 /** Node */
 struct SordNodeImpl {
-	const char* lang;         ///< Literal language (interned string)
-	SordNode*   datatype;     ///< Literal data type (ID of a URI node, or 0)
-	size_t      refs;         ///< Reference count (# of containing quads)
-	size_t      refs_as_obj;  ///< References as a quad object
-	SerdNode    node;         ///< Serd node
+	SerdNode node;  ///< Serd node
+	size_t   refs;  ///< Reference count (# of containing quads)
+	union {
+		SordResourceMetadata res;
+		SordLiteralMetadata  lit;
+	} meta;
 };
 
-const char*
-sord_intern_lang(SordWorld* world, const char* lang);
-
 #endif /* SORD_SORD_INTERNAL_H */
